====================================
``psyclone.psyir.nodes.array_mixin``
====================================

.. automodule:: psyclone.psyir.nodes.array_mixin

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.array_mixin


Classes
=======

- :py:class:`ArrayMixin`:
  Abstract class used to add functionality common to Nodes that represent


.. autoclass:: ArrayMixin
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ArrayMixin
      :parts: 1
